==> tellico_2.3.8+dfsg.1.orig.tar.xz: tellico-2.3.8/src/tests/isbndbfetchertest.h <==
/***************************************************************************
    Copyright (C) 2009-2011 Robby Stephenson <robby@periapsis.org>
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or         *
 *   modify it under the terms of the GNU General Public License as        *
 *   published by the Free Software Foundation; either version 2 of        *
 *   the License or (at your option) version 3 or any later version        *
 *   accepted by the membership of KDE e.V. (or its successor approved     *
 *   by the membership of KDE e.V.), which shall act as a proxy            *
 *   defined in Section 14 of version 3 of the license.                    *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
 *                                                                         *
 ***************************************************************************/

#ifndef ISBNDBFETCHERTEST_H
#define ISBNDBFETCHERTEST_H

#include "abstractfetchertest.h"

#include <QHash>

class ISBNdbFetcherTest : public AbstractFetcherTest {
Q_OBJECT
public:
  ISBNdbFetcherTest();

private Q_SLOTS:
  void initTestCase();
  void testIsbn();
  void testIsbn13();
  void testMultipleIsbn();
  void testTitle();
  void testAuthor();

private:
  QHash<QString, QString> m_fieldValues;
};

#endif

==> tellico_3.3.5.orig.tar.xz: tellico-3.3.5/src/tests/isbndbfetchertest.h <==
/***************************************************************************
    Copyright (C) 2009-2011 Robby Stephenson <robby@periapsis.org>
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or         *
 *   modify it under the terms of the GNU General Public License as        *
 *   published by the Free Software Foundation; either version 2 of        *
 *   the License or (at your option) version 3 or any later version        *
 *   accepted by the membership of KDE e.V. (or its successor approved     *
 *   by the membership of KDE e.V.), which shall act as a proxy            *
 *   defined in Section 14 of version 3 of the license.                    *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
 *                                                                         *
 ***************************************************************************/

#ifndef ISBNDBFETCHERTEST_H
#define ISBNDBFETCHERTEST_H

#include "abstractfetchertest.h"

#include <KConfig>

class ISBNdbFetcherTest : public AbstractFetcherTest {
Q_OBJECT
public:
  ISBNdbFetcherTest();

private Q_SLOTS:
  void initTestCase();
  void testIsbn();
  void testIsbn13();
  void testMultipleIsbn();
  void testTitle();
  void testAuthor();

private:
  bool m_hasConfigFile;
  KConfig m_config;
};

#endif
